==> istio-model-v1beta1-6.5.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPRedirectDerivePortFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRedirectDerivePortFluentImpl<A extends HTTPRedirectDerivePortFluent<A>> extends BaseFluent<A> implements HTTPRedirectDerivePortFluent<A>{
  public HTTPRedirectDerivePortFluentImpl() {
  }
  public HTTPRedirectDerivePortFluentImpl(HTTPRedirectDerivePort instance) {
    this.withDerivePort(instance.getDerivePort()); 
  }
  private HTTPRedirectRedirectPortSelection derivePort;
  public HTTPRedirectRedirectPortSelection getDerivePort() {
    return this.derivePort;
  }
  public A withDerivePort(HTTPRedirectRedirectPortSelection derivePort) {
    this.derivePort=derivePort; return (A) this;
  }
  public Boolean hasDerivePort() {
    return this.derivePort != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPRedirectDerivePortFluentImpl that = (HTTPRedirectDerivePortFluentImpl) o;
    if (derivePort != null ? !derivePort.equals(that.derivePort) :that.derivePort != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(derivePort,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (derivePort != null) { sb.append("derivePort:"); sb.append(derivePort); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPRedirectDerivePortFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRedirectDerivePortFluentImpl<A extends HTTPRedirectDerivePortFluent<A>> extends BaseFluent<A> implements HTTPRedirectDerivePortFluent<A>{
  public HTTPRedirectDerivePortFluentImpl() {
  }
  public HTTPRedirectDerivePortFluentImpl(HTTPRedirectDerivePort instance) {
    if (instance != null) {
      this.withDerivePort(instance.getDerivePort());
    }
  }
  private HTTPRedirectRedirectPortSelection derivePort;
  public HTTPRedirectRedirectPortSelection getDerivePort() {
    return this.derivePort;
  }
  public A withDerivePort(HTTPRedirectRedirectPortSelection derivePort) {
    this.derivePort=derivePort; return (A) this;
  }
  public Boolean hasDerivePort() {
    return this.derivePort != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRedirectDerivePortFluentImpl that = (HTTPRedirectDerivePortFluentImpl) o;
    if (!java.util.Objects.equals(derivePort, that.derivePort)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(derivePort,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (derivePort != null) { sb.append("derivePort:"); sb.append(derivePort); }
    sb.append("}");
    return sb.toString();
  }
  
}
